@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* ghex.h - defines GHex ;)
 
-   Copyright (C) 1997, 1998 Free Software Foundation
+   Copyright (C) 1998, 1999 Free Software Foundation
 
    GHex is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -35,6 +35,7 @@
 
 #define NO_BUFFER_LABEL "No buffer"
 #define DEFAULT_FONT    "-adobe-courier-medium-r-normal--12-*-*-*-*-*-*-*"
+#define MAX_MAX_UNDO_DEPTH 100000
 
 extern GnomeUIInfo help_menu[], file_menu[], view_menu[], main_menu[];
 
@@ -45,13 +46,13 @@ extern GnomeUIInfo help_menu[], file_menu[], view_menu[], main_menu[];
 
 #define CHILD_MENU_PATH GNOME_MENU_FILE_STRING
 #define CHILD_LIST_PATH GNOME_MENU_FILES_PATH
-#define GROUP_MENU_PATH(p) p = g_strconcat(GNOME_MENU_EDIT_PATH,_("Group Data As"),"/", NULL)
+#define GROUP_MENU_PATH(p) p = g_strconcat(GNOME_MENU_EDIT_PATH,_("_Group Data As"),"/", NULL)
 
 typedef struct _PropertyUI {
 	GnomePropertyBox *pbox;
 	GtkRadioButton *mdi_type[NUM_MDI_MODES];
 	GtkRadioButton *group_type[3];
-	GtkWidget *font_button;
+	GtkWidget *font_button, *spin;
 } PropertyUI;
 
 typedef struct _JumpDialog {
@@ -86,6 +87,9 @@ typedef struct _Converter {
 	gulong value;
 } Converter;
 
+extern int restarted;
+extern const struct poptOption options[];
+
 extern GnomeMDI *mdi;
 extern gint mdi_mode;
 
@@ -103,6 +107,8 @@ extern GtkCheckMenuItem *save_config_item;
 extern GdkFont *def_font;
 extern gchar *def_font_name;
 
+extern guint max_undo_depth;
+
 extern gint def_group_type;
 extern guint group_type[3];
 extern gchar *group_type_label[3];
@@ -123,9 +129,26 @@ void create_prefs_dialog   (PropertyUI *);
 void create_dialog_title   (GtkWidget *, gchar *);
 
 gint ask_user              (GnomeMessageBox *);
+GtkWidget *create_button   (GtkWidget *, gchar *, gchar *);
 
 /* config stuff */
 void save_configuration    (void);
 void load_configuration    (void);
 
+/* callbacks to nullify widget pointer after a delete event */
+gint delete_event_cb(GtkWidget *, gpointer, GtkWidget **);
+void cancel_cb(GtkWidget *, GtkWidget **);
+
+/* session managment */
+int save_state      (GnomeClient        *client,
+                     gint                phase,
+                     GnomeRestartStyle   save_style,
+                     gint                shutdown,
+                     GnomeInteractStyle  interact_style,
+                     gint                fast,
+                     gpointer            client_data);
+
+gint client_die     (GnomeClient *client, gpointer client_data);
+
+
 #endif
