@@ -190,74 +190,11 @@ session_die(GnomeClient *client)
 
 
 
-/*
- * argument parsing
- */
-
-static int w_x = 0, w_y = 0, w_w = 0, w_h = 0, w_xyset = 0, w_sx = 0, w_sy = 0;
-static char *geometry_string = NULL;
-
-static void
-parse_geometry(void)
-{
-	char *arg = geometry_string;
-
-	char *p, *p0;
-	char c;
-
-	if (!geometry_string)
-		return;
-	p = arg;
-	if ((*p >= '0') && (*p <= '9')) {
-		p0 = p;
-		for (; (*p >= '0') && (*p <= '9'); p++) ;
-		if (*p != 'x') {
-			g_print(_("error in geometry string \"%s\"\n"), arg);
-			return;
-		}
-		*p = 0;
-		w_w = atoi(p0);
-		*p = 'x';
-		p0 = ++p;
-		for (; (*p >= '0') && (*p <= '9'); p++) ;
-		c = *p;
-		*p = 0;
-		w_h = atoi(p0);
-		*p = c;
-	}
-	if (*p == 0)
-		return;
-	if ((*p != '-') && (*p != '+')) {
-		g_print(_("error in geometry string \"%s\"\n"), arg);
-		return;
-	}
-	p0 = p;
-	for (p++; (*p >= '0') && (*p <= '9'); p++) ;
-	c = *p;
-	*p = 0;
-	w_sx = (*p0 != '-');
-	w_x = atoi(p0);
-	*p = c;
-	if ((*p != '-') && (*p != '+')) {
-		g_print(_("error in geometry string \"%s\"\n"), arg);
-		return;
-	}
-	p0 = p;
-	for (p++; (*p >= '0') && (*p <= '9'); p++) ;
-	if (*p != 0) {
-		g_print(_("error in geometry string \"%s\"\n"), arg);
-		return;
-	}
-	w_sy = (*p0 != '-');
-	w_y = atoi(p0);
-	w_xyset++;
-}
-
-
 
 int 
 main(int argc, char *argv[])
 {
+	static char *geometry_string = NULL;
 #ifdef USE_SM
 	GnomeClient *client;
 #endif /* USE_SM */
@@ -272,7 +209,6 @@ main(int argc, char *argv[])
 
 	gnome_init_with_popt_table("gtt", VERSION, argc, argv,
 				   geo_options, 0, NULL);
-	parse_geometry();
 
 #ifdef USE_SM
 	client = gnome_master_client();
@@ -287,39 +223,7 @@ main(int argc, char *argv[])
 
 	signal(SIGCHLD, SIG_IGN);
 	lock_gtt();
-	app_new(argc, argv);
-	if (!w_w) {
-		gtk_widget_set_usize(glist, -1, 120);
-	}
-	gtk_widget_size_request(window, &window->requisition);
-	if (w_w != 0) {
-		if (window->requisition.width > w_w)
-			w_w = window->requisition.width;
-		if (window->requisition.height > w_h)
-			w_h = window->requisition.height;
-		gtk_widget_set_usize(window, w_w, w_h);
-	} else {
-		w_w = window->requisition.width;
-		w_h = window->requisition.height;
-	}
-	if (w_xyset) {
-		int t;
-		t = gdk_screen_width();
-		if (!w_sx)
-			w_x += t - w_w;
-		while (w_x < 0)
-			w_x += t;
-		while (w_x > t)
-			w_x -= t;
-		t = gdk_screen_height();
-		if (!w_sy)
-			w_y += t - w_h;
-		while (w_y < 0)
-			w_y += t;
-		while (w_y > t)
-			w_y -= t;
-		gtk_widget_set_uposition(window, w_x, w_y);
-	}
+	app_new(argc, argv, geometry_string);
 	gtk_signal_connect(GTK_OBJECT(window), "delete_event",
 			   GTK_SIGNAL_FUNC(quit_app), NULL);
 
