@@ -86,6 +86,7 @@
 #include <grp.h>
 /* #include "system.h" */ /* shared header for GNU shellutils, not in Gnome */
 #include <gnome.h>
+#include <errno.h>
 
 /* Fixme many of these conditionals don't actually exist in the 
    Gnome configure script. */
@@ -511,9 +512,11 @@ main (int argc, char **argv)
 
   gtk_init(&argc, &argv);
   gdk_imlib_init();
-  gnomelib_init(program_name); /* FIXME. Can't use gnome_init() because
-				  it would require redoing all the 
-				  existing arg parsing. */
+
+  gnomelib_init(program_name, VERSION);
+  /* FIXME. Can't use gnome_init() because
+     it would require redoing all the 
+     existing arg parsing. */
 
   fast_startup = 0;
   simulate_login = 0;
@@ -668,8 +671,8 @@ char * gui_getpass(void)
 
   gtk_container_border_width( GTK_CONTAINER(GNOME_DIALOG(dialog)->vbox), 
 			      GNOME_PAD );
-  gnome_dialog_set_destroy(GNOME_DIALOG(dialog), TRUE);
-  gnome_dialog_set_modal(GNOME_DIALOG(dialog));
+  gnome_dialog_set_close(GNOME_DIALOG(dialog), TRUE);
+  gtk_window_set_modal(GTK_WINDOW(dialog),TRUE);
   gnome_dialog_set_default(GNOME_DIALOG(dialog), 0); /* OK button */
 
   if ( strcmp(new_user, "root") == 0 ) {
@@ -680,7 +683,7 @@ char * gui_getpass(void)
 			     "Cancel if you do not know it.") );
   }
   else {
-     s = g_copy_strings( _("You are trying to change your user identity.\n"
+     s = g_strconcat( _("You are trying to change your user identity.\n"
 			   "Please enter the password for user `"),
 			 new_user, "'.", NULL );
      label = gtk_label_new(s);
