@@ -486,7 +486,10 @@ static void do_list_box(GtkWidget * box)
 {
   GtkCList * list;
   GtkWidget *sw;
-  const gchar * titles[] = { _("Category"), _("Your System") };
+  const gchar * titles[] = { N_("Category"), N_("Your System") };
+
+  titles[0]=_(titles[0]);
+  titles[1]=_(titles[1]);
 
   list = GTK_CLIST(create_clist(titles));
   sw = gtk_scrolled_window_new (NULL, NULL);
@@ -749,7 +752,7 @@ static void write_to_filestream(FILE * f)
       ;
     }
     else {
-      fprintf (f, "%-30s %s\n", descriptions[i], info[i]);
+      fprintf (f, "%-30s %s\n", _(descriptions[i]), info[i]);
     }
     ++i;
   }  
@@ -767,7 +770,7 @@ static gchar* write_to_string()
     }
     else {
       gchar buf[200];
-      g_snprintf (buf, 200, "%-30s %s\n", descriptions[i], info[i]);
+      g_snprintf (buf, 200, "%-30s %s\n", _(descriptions[i]), info[i]);
       tmp = g_strconcat(final ? final : "", buf, NULL);
       g_free(final);
       final = tmp;
@@ -789,7 +792,8 @@ static const gchar * scroll_text[] = {
 };
 
 static int nscroll_texts = sizeof (scroll_text) / sizeof (scroll_text[0]);
-static int scroll_text_widths[200] = { 0 };
+/* Add 7 to the size for Gnome 1.0 luck! */
+static int scroll_text_widths[sizeof(scroll_text)/sizeof(scroll_text[0])+7] = { 0 };
 static int cur_scroll_text = 0;
 static int cur_scroll_index = 0;
 
@@ -869,7 +873,7 @@ static int marquee_timer (gpointer data)
         {
         case 1:
           scroll_state = 2;
-          timer = gtk_timeout_add (700, marquee_timer, NULL);
+          timer = gtk_timeout_add (400, marquee_timer, NULL);
           return_val = FALSE;
           break;
         case 2:
